import React from 'react';
import ReactDOM from 'react-dom';
import DatePicker from 'rmc-date-picker/lib/DatePicker.js';
import moment from 'moment/moment';
import PopUp from 'ux-m-platform-popup';
import Footer from '@beisen-cmps/ux-m-platform-footer';
import Button from '@beisen-cmps/ux-m-platform-button';
import zhCn from './zh_CN';
import './index.scss';
import 'rmc-picker/assets/index.css';
import 'rmc-date-picker/assets/index.css';
// let map = {
// 		'yyyy/MM/dd HH:mm:ss' : "datetime"
// 		,'yyyy/MM/dd' : 'date'
// 		,'yyyy/MM' : 'month'
// 		,'HH:mm' : "time"
// 	}

export default class BlockDatePicker extends React.Component {
	static defaultProps = {
		mode: 'date',
		currentDate: new Date()
	};

	constructor(...args) {
		super(...args);
    	this.elementClientTop = 0;
		this.state = {
			isOpen: false,
			selectedDate: moment()
		};
		this.selectedDate = moment();
		this.lastConfirmDate = this.state.selectedDate.clone();
	}

  	componentDidMount() {
		if(this.refs.blockDatepicker) {
			this.elementClientTop = this.refs.blockDatepicker.getBoundingClientRect().top;
			this.$el = ReactDOM.findDOMNode(this);
			this.$el.addEventListener('touchmove',function(evt) {
				evt.stopPropagation();
			},false);
    	}
	}

	componentWillReciveprops(nextProps) {
		const newDate = moment(nextProps.currentDate);
		if (!this.state.selectedDate.isSame()) {
			this.state.setState({ selectedDate: newDate });
		}
	}

	componentDidUpdate() {
		if (this.state.isOpen) {
			document.body.classList.add('popup-active');
		} else {
			document.body.classList.remove('popup-active');
		}

		if(this.refs.blockDatepicker) {
		this.elementClientTop = this.refs.blockDatepicker.getBoundingClientRect().top;
		}
	}
	  
	componentWillUnMount() {
		this.$el && this.$el.removeEventListener('touchmove',function(evt) {
				evt.stopPropagation();
			},false);
	}

	displayFormat(date) {
		switch (this.props.mode) {
			case 'month':
				return `${date.year()}年${date.month() + 1}月`;
			case 'date':
				return `${date.year()}年${date.month() + 1}月${date.date()}日`;
			default:
				return '';
		}
	}

	handleClick() {
		this.setState({ isOpen: !this.state.isOpen });
	}

	handleCancel() {
		this.setState({ isOpen: false, selectedDate: this.lastConfirmDate });
	}

	handleConfim() {
		this.setState({ isOpen: false },function() {
				this.lastConfirmDate = this.selectedDate;
				this.props.onDateChange && this.props.onDateChange(this.selectedDate);
			}
		);
	}

	handleDateChange(dateObj) {
		this.selectedDate = dateObj;
    	this.setState({ selectedDate: this.selectedDate });
	}

	getContainer() {
		return this.refs.popContainer;
	}

	render() {
		return (
			<div ref="blockDatepicker">
				<div
					className="datepicker-block"
					onTouchTap={this.handleClick.bind(this)}
				>
					<span className="datepicker-title">
						{this.props.displayFormat
							? this.props.displayFormat(this.state.selectedDate)
							: this.displayFormat(this.state.selectedDate)}
					</span>
					<span className="datepicker-arrow" />
				</div>
				<div ref="popContainer" />
				<PopUp
					ref="popup"
					visible={this.state.isOpen}
					animation="topTool-slide-fade"
					maskAnimation="fade"
					onClose={this.handleCancel.bind(this)}
					isFullPage={true}
					maskStyle={{ zIndex: '1',top: this.elementClientTop }}
          			style={{ top: '44px' }}
					wrapClassName="datepicker_wrap"
					getContainer={this.getContainer.bind(this)}
				>
					<div>
						<DatePicker
							date={this.state.selectedDate}
							mode={this.props.mode}
							locale={zhCn(this.props.mode)}
							minDate={this.props.minDate || moment([1900, 1, 1, 0, 0, 0])}
							maxDate={this.props.maxDate || moment([2050, 1, 1, 23, 59, 59])}
							onDateChange={this.handleDateChange.bind(this)}
						/>
						<Footer cls="searchItem-footer-border">
								<Button cls='btn_empty' text='取消' onTouchTap={this.handleCancel.bind(this)} />
								<Button cls='btn_submit' text='确定' onTouchTap={this.handleConfim.bind(this)} />
						</Footer>
					</div>
				</PopUp>
			</div>
		);
	}
}
